@@ -3,7 +3,7 @@
 #
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 1999-2008 Chris Lawrence
-#   Copyright (C) 2008-2022 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2023 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -205,10 +205,6 @@ debother = {
     'www.debian.org': 'Problems with the WWW site'
 }
 
-progenyother = {
-    'debian-general': 'Any non-package-specific bug',
-}
-
 
 def check_package_info(package):
     """
@@ -256,7 +252,7 @@ def check_package_info(package):
 
 
 def add_affects_package(info, package, pseudos, ui):
-    src_pkg = info[12] or package
+    src_pkg = info and info[12] or package
     pseudos.append('Control: affects -1 + src:%s' % src_pkg)
     pseudos.append('X-Debbugs-Cc: %s@packages.debian.org' % src_pkg)
     ui.log_message('Your report will be carbon-copied to the package maintainer.\n')
@@ -417,6 +413,7 @@ def handle_debian_ftp(package, bts, ui, fromaddr, timeout, online=True, http_pro
             'main': "",
             'contrib': "",
             'non-free': "",
+            'non-free-firmware': "",
         }, 'Choose the archive section: ', default='main', empty_ok=True)
         if not arch_section:
             arch_section = 'main'
@@ -592,7 +589,7 @@ def handle_debian_release(package, bts, ui, fromaddr, timeout, online=True, http
 
         if info:
             package = info[12] or package
-            version = info[0]
+            version = utils.get_source_version(package) or info[0]
 
         if online and tag.endswith('-pu'):
             try:
@@ -1266,7 +1263,7 @@ SYSTEMS = {
     'debian': {
         'name': 'Debian',
         'email': '%s@bugs.debian.org',
-        'btsroot': 'http://www.debian.org/Bugs/',
+        'btsroot': 'https://www.debian.org/Bugs/',
         'otherpkgs': debother,
         'nonvirtual': ['linux-image', 'kernel-image'],
         'specials': {
@@ -1332,7 +1329,7 @@ TAGS = {
 }
 
 
-def get_tags(severity='', mode=utils.MODE_NOVICE):
+def get_tags(severity='', mode=utils.MODE.NOVICE):
     """
     Return list of tags supported by the bug tracking system
 
@@ -1357,9 +1354,9 @@ def get_tags(severity='', mode=utils.MODE_NOVICE):
     if severity in ('grave', 'critical', 'serious'):
         tags.update(CRITICAL_TAGS)
 
-    if mode > utils.MODE_STANDARD:
+    if mode > utils.MODE.STANDARD:
         tags.update(EXPERT_TAGS)
-    elif mode < utils.MODE_STANDARD and 'newcomer' in tags:
+    elif mode < utils.MODE.STANDARD and 'newcomer' in tags:
         # do not show the newcomer tag in novice mode
         del tags['newcomer']
 
