@@ -1,7 +1,7 @@
 # urwid user interface for reportbug
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 2006-08 Chris Lawrence
-#   Copyright (C) 2008-2022 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2023 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -405,7 +405,12 @@ def menu(par, options, prompt, default=None, title=None, any_ok=False,
     else:
         extras = list(extras)
 
-    if not default:
+    if multiple:
+        if default is None:
+            default = []
+        elif isinstance(default, str):
+            default = [default]
+    elif not default:
         default = ''
 
     if title:
@@ -442,7 +447,7 @@ def menu(par, options, prompt, default=None, title=None, any_ok=False,
     options = opts
 
     if multiple:
-        widgets = [(urwid.CheckBox(option, state=(option == default)),
+        widgets = [(urwid.CheckBox(option, state=(option in default)),
                     desc or '') for (option, desc) in options]
         box = checklistdialog(par, widgets, height=('relative', 80),
                               title=title)
@@ -501,9 +506,10 @@ def get_filename(prompt, title=None, force_prompt=False, default=''):
                       default=default)
 
 
-def select_multiple(par, options, prompt, title=None, order=None, extras=None):
-    return menu(par, options, prompt, title=title, order=order, extras=extras,
-                multiple=True, empty_ok=False)
+def select_multiple(par, options, prompt, default=None, title=None,
+                    order=None, extras=None):
+    return menu(par, options, prompt, default=default, title=title,
+                order=order, extras=extras, multiple=True, empty_ok=False)
 
 
 # Things that are very UI dependent go here
