@@ -2,7 +2,7 @@
 # utils module - common functions for reportbug UIs
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   Copyright (C) 1999-2008 Chris Lawrence
-#   Copyright (C) 2008-2022 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2023 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -37,11 +37,12 @@ except ImportError as e:
 import shlex
 import email
 import email.policy
+import enum
 import socket
 import subprocess
-import apt
 import gzip
 
+import apt
 from .urlutils import open_url
 from .mailer import MUA
 
@@ -50,7 +51,7 @@ PSEUDOHEADERS = ('Package', 'Source', 'Version', 'Severity', 'File', 'Tags',
                  'Justification', 'Followup-For', 'Owner', 'User', 'Usertags',
                  'Forwarded', 'Control', 'X-Debbugs-Cc')
 # These pseudo-headers can be repeated in the report
-REPEATABLE_PSEUDOHEADERS = ['Control', ]
+REPEATABLE_PSEUDOHEADERS = ['Control', 'User', 'Usertags']
 
 MODES = {'novice': 'Offer simple prompts, bypassing technical questions.',
          'standard': 'Offer more extensive prompts, including asking about '
@@ -61,12 +62,18 @@ MODES = {'novice': 'Offer simple prompts, bypassing technical questions.',
          'expert': 'Bypass most handholding measures and preliminary triage '
                    'routines.  This mode should not be used by people unfamiliar with '
                    'Debian\'s policies and operating procedures.'}
-MODELIST = ['novice', 'standard', 'advanced', 'expert']
-for mode in MODELIST:
-    exec('MODE_%s=%d' % (mode.upper(), MODELIST.index(mode)))
-del mode
 
-# moved here since it needs the MODE_* vars to be defined
+
+class MODE(enum.IntEnum):
+    NOVICE = 0
+    STANDARD = 1
+    ADVANCED = 2
+    EXPERT = 3
+
+
+MODELIST = [m.name.lower() for m in MODE]
+
+# moved here since it needs the MODE.* vars to be defined
 from . import debbugs   # noqa: E402
 from reportbug.ui import AVAILABLE_UIS   # noqa: E402
 
@@ -573,7 +580,7 @@ def get_user_id(emailaddr='', realname='', charset='utf-8'):
     return email.utils.formataddr((realname, emailaddr))
 
 
-statuscache = {}
+statuscache: dict[str, tuple] = {}
 
 
 def get_package_status(package, avail=False):
@@ -599,8 +606,8 @@ def get_package_status(package, avail=False):
             representing alternative dependencies
         3.  recommended packages as a tuple containing lists, each list
             representing alternative recommends
-        4.  conffiles as a tuple containing (filename_str, md5sum_str)
-            tuples
+        4.  conffiles as a tuple containing (filename_str, md5sum_str,
+            flag_str) tuples
         5.  maintainer name and email address string
         6.  bool indicating whether the package is installed
         7.  origin (content of "Origin:" package header if available)
@@ -688,7 +695,7 @@ def get_package_status(package, avail=False):
                 confmode = False
             else:
                 # re is used to identify also conffiles with spaces in the name
-                conffiles += re.findall(r' (.+) ([0-9a-f]+).*$', line)
+                conffiles += re.findall(r' (.+) ([0-9a-f]+|newconffile)(?: (.+))?$', line)
 
         if versionre.match(line):
             (crud, pkgversion) = line.split(": ", 1)
@@ -1172,8 +1179,8 @@ def get_changed_config_files(conffiles, nocompress=False):
 
     Parameters
     ----------
-    conffiles : [(str, str), ...]
-        List of (filename, md5sum) tuples
+    conffiles : [(str, str, str), ...]
+        List of (filename, md5sum, flag) tuples
     nocompress : bool
         determines whether empty lines and comment lines should be
         included in the output
@@ -1189,11 +1196,18 @@ def get_changed_config_files(conffiles, nocompress=False):
     """
     confinfo = {}
     changed = []
-    for (filename, md5sum) in conffiles:
+    for (filename, md5sum, flag) in conffiles:
         try:
             with open(filename, errors='backslashreplace') as fp:
                 lines = fp.readlines()
+        except FileNotFoundError:
+            if flag in ("obsolete", "remove-on-upgrade"):
+                continue
+            confinfo[filename] = "[file not found]"
+            continue
         except OSError as msg:
+            if flag in ("obsolete", "remove-on-upgrade"):
+                continue
             confinfo[filename] = msg
             continue
 
@@ -1337,7 +1351,7 @@ def get_merged_usr():
 def generate_blank_report(package, pkgversion, severity, justification,
                           depinfo, confinfo, foundfile='', incfiles='',
                           system='debian', exinfo=None, type=None, klass='',
-                          subject='', tags='', body='', mode=MODE_EXPERT,  # noqa: F821
+                          subject='', tags='', body='', mode=MODE.EXPERT,  # noqa: F821
                           pseudos=None, debsumsoutput=None, issource=False,
                           options=None):
     """
@@ -1879,7 +1893,7 @@ def check_package_name(pkg):
     Check the package name against Debian Policy
 
     Package names must comply with the policy requirements:
-    https://www.debian.org/doc/debian-policy/ch-controlfields.html#s-f-Source
+    https://www.debian.org/doc/debian-policy/ch-controlfields.html#s-f-source
 
     Returns
     -------
